# How to install

The `fractal_tasks_core` Python package is hosted on PyPI ([https://pypi.org/project/fractal-tasks-core](https://pypi.org/project/fractal-tasks-core)), and can be installed via `pip`:

```console
pip install fractal-tasks-core
```

If you collect this package on Fractal server to run the tasks, make sure to use the package name `fractal-tasks-core` in the corresponding field.
